@@ -16,7 +16,7 @@
 * limitations under the License.
 */
 
-#include "oned/ODRowReader.h"
+#include "ODRowReader.h"
 
 namespace ZXing {
 
@@ -37,7 +37,7 @@ public:
 	Result decodeRow(int rowNumber, const BitArray& row, std::unique_ptr<DecodingState>& state) const override;
 
 private:
-	bool _shouldReturnStartEnd;
+	bool _returnStartEnd;
 };
 
 } // OneD
